@@ -146,9 +146,9 @@ class DFUAdapter:
         while finished is False:
             byte = self.serial_port.read(1)
             if byte:
-                (byte) = struct.unpack("B", byte)[0]
+                (unpacked_byte) = struct.unpack("B", byte)[0]
                 (finished, current_state, decoded_data) = Slip.decode_add_byte(
-                    byte, decoded_data, current_state
+                    unpacked_byte, decoded_data, current_state
                 )
             else:
                 current_state = Slip.SLIP_STATE_CLEARING_INVALID_PACKET
